# DetailedWorkflowType

The type of the workflow. Currently the only valid value is 'Workflow::Setup'. 

## Enum

* `WORKFLOW_COLON_COLON_SETUP` (value: `'Workflow::Setup'`)

* `WORKFLOW_COLON_COLON_INSTANCE` (value: `'Workflow::Instance'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


